#define INCL_PM
#define INCL_DOS
#include <os2.h>
#include <stdlib.h>
#include "wcapi.h"                      /* WatchCat API functions */

/***************************************************************************/
/*                                                                         */
/*  This example shows how to integrate your own routines in WatchCat      */
/*  Just write a DLL like this file. You don't need to supply all          */
/*  functions. See watchcat.inf for more information.                      */
/*                                                                         */
/*  Note:                                                                  */
/*     1) The DLL must reside in the WatchCat directory                    */
/*     2) This is an example. IT DOES SLOW DOWN WATCHCAT. PLEASE DELETE    */
/*        THIS SAMPLE DLL IF IT IS NOT NEEDED ANY LONGER.                  */
/*     3) If you are using C++, please use extern "C" linkage for all      */
/*        functions that are exported.                                     */
/*     4) If you're not running multiple instance or you're not using      */
/*        static/global data you can also use delete the DATA MULTIPLE     */
/*        statement in your .DEF file.  (testmod uses static data (e.g.    */
/*        the counter, the window handles).                                */
/*                                                                         */
/*  How to compile: (hope this is correct)                                 */
/*                                                                         */
/*  BORLAND:                                                               */
/*     bcc -sd testmod.c dllbase.c                                         */
/*       -sd    create DLL                                                 */
/*                                                                         */
/*  EMX:                                                                   */
/*     gcc -o testmod.dll -Zomf -Zdll testmod.c dllbase.c testmod.def      */
/*       -o ... output name (must match the name in .DEF FILE)             */
/*       -Zomf  create .obj, creating .LIBs might be necessary.            */
/*       -Zdll  create .DLL                                                */
/*     Note: It is necessary to export some functions. As far as we know,  */
/*           EMX does not support a export-keyword. Therefore all exported */
/*           symbols must appear in the .DEF-file.                         */
/*                                                                         */
/*  IBM:                                                                   */
/*     icc -Rn -Ge- testmod.c dllbase.c testmod.def                        */
/*       -Rn    subsystem DLL. Recommended. Read IBM Docs for init         */
/*              C-Lib when NOT using -Rn                                   */
/*       -Ge-   create DLL                                                 */
/*                                                                         */
/*  WATCOM:                                                                */
/*     wcl386 -c -s -bd testmod.c dllbase.c                                */
/*     wlink @testmod.lnk                                                  */
/*       -c     compile only. (It seems to be necessary to link via wlink) */
/*       -s     remove stack probes                                        */
/*       -bd    create DLL                                                 */
/***************************************************************************/

void *win_action;               /* The window handle for the action window */
void *win_timer;                /* The timer window                        */

/* The following functions are event-driven response functions             */
/* They are called by WatchCat if an event occurs. Please note that these  */
/* functions must be exported.                                             */

BOOL WCEXPORT WCSYSTEM WCatKey(void *win, int scan, int ascii, int shift)
  {
  if (win!=win_action)
     return FALSE;

  WCatPrintf(win_action, "Key: scan=%i, ascii=%i, shift=%i",
        scan, ascii, shift);

  return FALSE;
  }

BOOL WCEXPORT WCSYSTEM WCatB1Click(void *win, int x, int y)
  {
  if (win!=win_action)
     return FALSE;

  WCatPrintf(win_action, "Button 1: window: %x, x=%i, y=%i", win, x, y);

  return FALSE;
  }

BOOL WCEXPORT WCSYSTEM WCatInformIfProcessChanged(void *win, int line)
  {
  ULONG handle, pid;
  char name[50];

  /*
  if (win!=win_action)
     return FALSE;
  */

  /* Oh, a new process/module has been selected with Enter */
  /* what module is it?                                    */
  handle=WCatQueryPID();
  handle=WCatQueryHandle();

  /* Currently there is no other way to get the name than the following: */
  if (DosQueryModuleName(handle, sizeof(name), name))
     name[0]=0;                         /* return code !=0 : error       */

  WCatPrintf(win_action, "new module: handle=%x, pid=%x, name: %s",
                         handle, pid, name);

  return FALSE;                         /* default action                */
  }

/* This function is the timer thread. It is called by WatchCat every     */
/* second                                                                */

void WCEXPORT WCSYSTEM WCatTimer()
   {
   static int count=1;
   WCatPrintf(win_timer, "called %i times", count++);
   }

/* The following two functions are displayed when the associated */
/* window entry is selected. They do the default action: simply  */
/* display the window.                                           */

static void show_win_action()
  {
  WCatShowWindow(win_action);
  }

static void show_win_timer()
  {
  WCatShowWindow(win_timer);
  }

BOOL WCEXPORT WCSYSTEM WCatInit()
  {
  win_action=WCatBegWindow("Action",                       /* title           */
                           "Action window",                /* menu entry      */
                           "An example to accept action",  /* explanation     */
                           show_win_action);               /* function        */

  win_timer= WCatBegWindow("Timer",                        /* title           */
                           "Timer window",                 /* menu entry      */
                           "An example timer",             /* explanation     */
                           show_win_timer);                /* function        */
  return TRUE;
  }
